//! Attributes to a fenced code block.
//!
//! These are inspired by the Pandoc [`fenced_code_attributes`
//! extension](https://pandoc.org/chunkedhtml-demo/8.5-verbatim-code-blocks.html).

#[derive(Debug, Clone, Eq, PartialEq)]
enum BlockAttr {
    Id(String),
    Class(String),
    KeyValue(String, String),
}

impl BlockAttr {
    fn parse(s: &str) -> Result<Vec<Self>, BlockAttrError> {
        let s = s.trim();
        if s.starts_with('{') {
            panic!();
        } else {
            let words: Vec<&str> = s.split_ascii_whitespace().collect();
            if words.len() == 0 {
                return Ok(vec![]);
            } else if words.len() == 1 {
                return Ok(vec![Self::Class(words[0].into())]);
            } else {
                panic!();
            }
        }
    }
}

#[derive(Debug, thiserror::Error)]
enum BlockAttrError {}

#[cfg(test)]
mod test {
    use super::BlockAttr;

    #[test]
    fn empty_string() {
        assert_eq!(BlockAttr::parse("").unwrap(), vec![]);
    }

    #[test]
    fn just_word() {
        assert_eq!(
            BlockAttr::parse("file").unwrap(),
            vec![BlockAttr::Class("file".into())]
        );
    }
}
